var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var SharedCommand_1;
import { EmbedBuilder, time, TimestampStyles } from '@discordjs/builders';
import { Command, container, RegisterCommand } from '@skyra/http-framework';
import { applyLocalizedBuilder, getSupportedUserLanguageT } from '@skyra/http-framework-i18n';
import { ButtonStyle, ComponentType, MessageFlags } from 'discord-api-types/v10';
import { cpus, uptime } from 'node:os';
import { LanguageKeys } from '../lib/i18n/LanguageKeys.js';
import { getInvite, getRepository } from '../lib/information.js';
let SharedCommand = SharedCommand_1 = class SharedCommand extends Command {
    chatInputRun(interaction) {
        const t = getSupportedUserLanguageT(interaction);
        const embed = new EmbedBuilder()
            .setDescription(t(LanguageKeys.Commands.Shared.InfoEmbedDescription))
            .addFields(this.getUptimeStatistics(t), this.getServerUsageStatistics(t));
        const components = this.getComponents(t);
        return interaction.reply({ embeds: [embed.toJSON()], components, flags: MessageFlags.Ephemeral });
    }
    getUptimeStatistics(t) {
        const now = Date.now();
        const nowSeconds = Math.round(now / 1000);
        return {
            name: t(LanguageKeys.Commands.Shared.InfoFieldUptimeTitle),
            value: t(LanguageKeys.Commands.Shared.InfoFieldUptimeValue, {
                host: time(Math.round(nowSeconds - uptime()), TimestampStyles.RelativeTime),
                client: time(Math.round(nowSeconds - process.uptime()), TimestampStyles.RelativeTime)
            })
        };
    }
    getServerUsageStatistics(t) {
        const usage = process.memoryUsage();
        return {
            name: t(LanguageKeys.Commands.Shared.InfoFieldServerUsageTitle),
            value: t(LanguageKeys.Commands.Shared.InfoFieldServerUsageValue, {
                cpu: cpus().map(SharedCommand_1.formatCpuInfo.bind(null)).join(' | '),
                heapUsed: (usage.heapUsed / 1048576).toLocaleString(t.lng, { maximumFractionDigits: 2 }),
                heapTotal: (usage.heapTotal / 1048576).toLocaleString(t.lng, { maximumFractionDigits: 2 })
            })
        };
    }
    getComponents(t) {
        const url = getInvite();
        const support = this.getSupportComponent(t);
        const github = this.getGitHubComponent(t);
        const donate = this.getDonateComponent(t);
        const data = url
            ? [this.getActionRow(support, this.getInviteComponent(t, url)), this.getActionRow(github, donate)]
            : [this.getActionRow(support, github, donate)];
        return data;
    }
    getActionRow(...components) {
        return { type: ComponentType.ActionRow, components };
    }
    getSupportComponent(t) {
        return {
            type: ComponentType.Button,
            style: ButtonStyle.Link,
            label: t(LanguageKeys.Commands.Shared.InfoButtonSupport),
            emoji: { name: '🆘' },
            url: 'https://discord.gg/6gakFR2'
        };
    }
    getInviteComponent(t, url) {
        return {
            type: ComponentType.Button,
            style: ButtonStyle.Link,
            label: t(LanguageKeys.Commands.Shared.InfoButtonInvite),
            emoji: { name: '🎉' },
            url
        };
    }
    getGitHubComponent(t) {
        return {
            type: ComponentType.Button,
            style: ButtonStyle.Link,
            label: t(LanguageKeys.Commands.Shared.InfoButtonGitHub),
            emoji: { id: '950888087188283422', name: 'github2' },
            url: getRepository()
        };
    }
    getDonateComponent(t) {
        return {
            type: ComponentType.Button,
            style: ButtonStyle.Link,
            label: t(LanguageKeys.Commands.Shared.InfoButtonDonate),
            emoji: { name: '🧡' },
            url: 'https://donate.skyra.pw'
        };
    }
    static formatCpuInfo({ times }) {
        return `${Math.round(((times.user + times.nice + times.sys + times.irq) / times.idle) * 10000) / 100}%`;
    }
};
SharedCommand = SharedCommand_1 = __decorate([
    RegisterCommand((builder) => applyLocalizedBuilder(builder, 'commands/shared:info'))
], SharedCommand);
export { SharedCommand };
void container.stores.loadPiece({ name: 'info', piece: SharedCommand, store: 'commands' });
//# sourceMappingURL=info.js.map